==> senior_design_system-0.17.0.tar.gz: lib/components/senior_quotes/senior_quotes_widget.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_quotes_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorQuotes extends StatelessWidget {
  SeniorQuotes({
    Key? key,
    this.isScrollable = false,
    required this.message,
    this.style,
  }) : super(key: key);

  final bool? isScrollable;
  final String message;
  final SeniorQuotesStyle? style;

  final ScrollController scrollController = ScrollController();

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return isScrollable! ? _buildQuotes(theme, defaultTheme) : _buildExpandedQuotes(theme, defaultTheme);
  }

  Widget _buildQuotes(SeniorTheme? theme, SeniorTheme defaultTheme) {
    final Color textColor = style?.textColor ??
        theme?.quotesTheme?.style?.textColor ??
        defaultTheme.quotesTheme?.style?.textColor ??
        SeniorColors.neutralColor800;

    return Expanded(
      child: Container(
        margin: const EdgeInsets.only(
          right: SeniorSpacing.normal,
          left: SeniorSpacing.normal,
        ),
        width: double.infinity,
        decoration: BoxDecoration(
          color: style?.backgroundColor ??
              theme?.quotesTheme?.style?.backgroundColor ??
              defaultTheme.quotesTheme?.style?.backgroundColor ??
              SeniorColors.secondaryColor100,
          borderRadius: BorderRadius.circular(SeniorRadius.xbig),
        ),
        child: Stack(
          children: [
            Padding(
              padding: EdgeInsets.only(
                top: 55.0,
                bottom: 50.0,
                right: 5.0,
              ),
              child: Scrollbar(
                isAlwaysShown: true,
                controller: scrollController,
                child: SingleChildScrollView(
                  controller: scrollController,
                  padding: EdgeInsets.symmetric(
                    horizontal: 40.0,
                  ),
                  child: Text(
                    message,
                    style: SeniorTypography.text(
                      color: textColor,
                    ),
                  ),
                ),
              ),
            ),
            Positioned(
              top: 20.0,
              left: 20.0,
              child: Text(
                '“',
                style: SeniorTypography.h1(
                  color: textColor,
                ),
              ),
            ),
            Positioned(
              bottom: 0.0,
              right: 20.0,
              child: Text(
                '”',
                style: SeniorTypography.h1(
                  color: textColor,
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildExpandedQuotes(SeniorTheme? theme, SeniorTheme defaultTheme) {
    final Color textColor = style?.textColor ??
        theme?.quotesTheme?.style?.textColor ??
        defaultTheme.quotesTheme?.style?.textColor ??
        SeniorColors.neutralColor800;

    return Container(
      decoration: BoxDecoration(
        color: style?.backgroundColor ??
            theme?.quotesTheme?.style?.backgroundColor ??
            defaultTheme.quotesTheme?.style?.backgroundColor ??
            SeniorColors.secondaryColor100,
        borderRadius: BorderRadius.circular(SeniorRadius.xbig),
      ),
      child: Stack(
        children: [
          Padding(
            padding: EdgeInsets.only(
              top: 55.0,
              bottom: 50.0,
              right: 40.0,
              left: 40.0,
            ),
            child: Text(
              message,
              style: SeniorTypography.text(
                color: textColor,
              ),
            ),
          ),
          Positioned(
            top: 20.0,
            left: 20.0,
            child: Text(
              '“',
              style: SeniorTypography.h1(
                color: textColor,
              ),
            ),
          ),
          Positioned(
            bottom: 0.0,
            right: 20.0,
            child: Text(
              '”',
              style: SeniorTypography.h1(
                color: textColor,
              ),
            ),
          ),
        ],
      ),
    );
  }
}

==> senior_design_system-0.26.2.tar.gz: lib/components/senior_quotes/senior_quotes_widget.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_quotes_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorQuotes extends StatelessWidget {
  /// Creates the SDS SeniorQuotes component.
  ///
  /// The parameter [message] is required.
  SeniorQuotes({
    Key? key,
    this.isScrollable = false,
    required this.message,
    this.style,
  }) : super(key: key);

  /// Whether the content will be scrollable.
  ///
  /// The default value is false.
  final bool? isScrollable;

  /// The message that will be displayed on the component.
  final String message;

  /// The component's style definitions.
  /// Allows you to configure:
  /// [SeniorQuotesStyle.backgroundColor] the component's background color.
  /// [SeniorQuotesStyle.textColor] the text color in the component.
  final SeniorQuotesStyle? style;

  final ScrollController scrollController = ScrollController();

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme =
        SeniorThemeProvider.getDefaultTheme(context);

    return isScrollable!
        ? _buildQuotes(theme, defaultTheme)
        : _buildExpandedQuotes(theme, defaultTheme);
  }

  Widget _buildQuotes(SeniorTheme? theme, SeniorTheme defaultTheme) {
    final Color textColor = style?.textColor ??
        theme?.quotesTheme?.style?.textColor ??
        defaultTheme.quotesTheme?.style?.textColor ??
        SeniorColors.neutralColor800;

    return Expanded(
      child: Container(
        margin: const EdgeInsets.only(
          right: SeniorSpacing.normal,
          left: SeniorSpacing.normal,
        ),
        width: double.infinity,
        decoration: BoxDecoration(
          color: style?.backgroundColor ??
              theme?.quotesTheme?.style?.backgroundColor ??
              defaultTheme.quotesTheme?.style?.backgroundColor ??
              SeniorColors.secondaryColor100,
          borderRadius: BorderRadius.circular(SeniorRadius.xbig),
        ),
        child: Stack(
          children: [
            Padding(
              padding: const EdgeInsets.only(
                top: 55.0,
                bottom: 50.0,
                right: 5.0,
              ),
              child: Scrollbar(
                thumbVisibility: true,
                controller: scrollController,
                child: SingleChildScrollView(
                  controller: scrollController,
                  padding: const EdgeInsets.symmetric(
                    horizontal: 40.0,
                  ),
                  child: Text(
                    message,
                    style: SeniorTypography.text(
                      color: textColor,
                    ),
                  ),
                ),
              ),
            ),
            Positioned(
              top: 20.0,
              left: 20.0,
              child: Text(
                '“',
                style: SeniorTypography.h1(
                  color: textColor,
                ),
              ),
            ),
            Positioned(
              bottom: 0.0,
              right: 20.0,
              child: Text(
                '”',
                style: SeniorTypography.h1(
                  color: textColor,
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildExpandedQuotes(SeniorTheme? theme, SeniorTheme defaultTheme) {
    final Color textColor = style?.textColor ??
        theme?.quotesTheme?.style?.textColor ??
        defaultTheme.quotesTheme?.style?.textColor ??
        SeniorColors.neutralColor800;

    return Container(
      decoration: BoxDecoration(
        color: style?.backgroundColor ??
            theme?.quotesTheme?.style?.backgroundColor ??
            defaultTheme.quotesTheme?.style?.backgroundColor ??
            SeniorColors.secondaryColor100,
        borderRadius: BorderRadius.circular(SeniorRadius.xbig),
      ),
      child: Stack(
        children: [
          Padding(
            padding: const EdgeInsets.only(
              top: 55.0,
              bottom: 50.0,
              right: 40.0,
              left: 40.0,
            ),
            child: Text(
              message,
              style: SeniorTypography.text(
                color: textColor,
              ),
            ),
          ),
          Positioned(
            top: 20.0,
            left: 20.0,
            child: Text(
              '“',
              style: SeniorTypography.h1(
                color: textColor,
              ),
            ),
          ),
          Positioned(
            bottom: 0.0,
            right: 20.0,
            child: Text(
              '”',
              style: SeniorTypography.h1(
                color: textColor,
              ),
            ),
          ),
        ],
      ),
    );
  }
}
